==> fet_6.7.6.orig.tar.bz2: fet-6.7.6/src/interface/addconstraintteacherminafternoonsperweekform.h <==
/***************************************************************************
                          addconstraintteacherminafternoonsperweekform.h  -  description
                             -------------------
    begin                : 2009
    copyright            : (C) 2009 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTTEACHERMINAFTERNOONSPERWEEKFORM_H
#define ADDCONSTRAINTTEACHERMINAFTERNOONSPERWEEKFORM_H

#include "ui_addconstraintteacherminafternoonsperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class AddConstraintTeacherMinAfternoonsPerWeekForm : public QDialog, Ui::AddConstraintTeacherMinAfternoonsPerWeekForm_template  {
	Q_OBJECT
public:
	AddConstraintTeacherMinAfternoonsPerWeekForm(QWidget* parent);
	~AddConstraintTeacherMinAfternoonsPerWeekForm();

	void updateMinAfternoonsSpinBox();
	void updateTeachersComboBox();

public slots:
	void addCurrentConstraint();
};

#endif

==> fet_6.8.5.orig.tar.bz2: fet-6.8.5/src/interface/addconstraintteacherminafternoonsperweekform.h <==
/***************************************************************************
                          addconstraintteacherminafternoonsperweekform.h  -  description
                             -------------------
    begin                : 2009
    copyright            : (C) 2009 by Liviu Lalescu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find there the email address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTTEACHERMINAFTERNOONSPERWEEKFORM_H
#define ADDCONSTRAINTTEACHERMINAFTERNOONSPERWEEKFORM_H

#include "ui_addconstraintteacherminafternoonsperweekform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class AddConstraintTeacherMinAfternoonsPerWeekForm : public QDialog, Ui::AddConstraintTeacherMinAfternoonsPerWeekForm_template  {
	Q_OBJECT
public:
	AddConstraintTeacherMinAfternoonsPerWeekForm(QWidget* parent);
	~AddConstraintTeacherMinAfternoonsPerWeekForm();

	void updateMinAfternoonsSpinBox();
	void updateTeachersComboBox();

public slots:
	void addCurrentConstraint();
};

#endif
